@@ -1,9 +1,11 @@
 import os
 import sys
 import uuid
+import tarfile
+import zipfile
 from time import sleep
 
-version = "0.0.29"
+version = "0.0.34"
 
 try:
     from uuid import uuid4
@@ -29,6 +31,7 @@ try:
     from itsdangerous.exc import BadSignature
     from shutil import rmtree, make_archive
     from unicodedata import normalize
+    from pathlib import Path
     import re
     import aiofiles
     import logging
@@ -45,6 +48,21 @@ except AssertionError:
 AUTH_DB_PATH = "{}/auth.db".format(CONFIG["CIRCE_WORKING_DIR"])
 
 
+def _convert_targz_to_zip(tgz_path: str, zip_path: str):
+    tar_file = tarfile.open(name=tgz_path, mode="r|gz")
+    zip_file = zipfile.ZipFile(
+        file=zip_path, mode="a", compression=zipfile.ZIP_DEFLATED
+    )
+    for item in tar_file:
+        if item.name:
+            f = tar_file.extractfile(item)
+            fl = f.read()
+            fn = item.name
+            zip_file.writestr(fn, fl)
+    tar_file.close()
+    zip_file.close()
+
+
 @contextmanager
 def auth_db(readonly=True):
     """
@@ -129,7 +147,9 @@ def _check_port(host, port):
 def _make_homepage():
     tpl = (
         "<!DOCTYPE html>"
-        '<html lang="fr"><head><meta charset="UTF-8"/><title>Circe - Transformations de documents</title>'
+        '<html lang="fr"><head><meta charset="UTF-8"/><title>Circe '
+        + version
+        + " - Transformations de documents</title>"
         "<style>"
         "body{{font-family: sans-serif;color:#495057;}}"
         "pre{{color:#c5c8c6; background-color:#1d1f21;padding:10px;line-height:0.8em;border-radius:5px;}}"
@@ -179,6 +199,11 @@ async def index(request: sanic.request):
     return sanic.response.html(STATIC_HOMEPAGE_HTML)
 
 
+@server.get("/version/")
+async def index(request: sanic.request):
+    return sanic.response.text(version)
+
+
 @server.get("/transformations/")
 async def transformations(request: sanic.request):
     return sanic.response.HTTPResponse(
@@ -196,6 +221,13 @@ async def job_get(request: sanic.request, job_id: str):
         return sanic.response.HTTPResponse("Accepted", status=202)
     result_file_path = "{}/done/{}.tar.gz".format(CONFIG["CIRCE_WORKING_DIR"], job_id)
     if os.path.isfile(result_file_path):
+        if request.args.get("zip", None):
+            result_zip_path = "{}done/{}.zip".format(
+                CONFIG["CIRCE_WORKING_DIR"], job_id
+            )
+            if not os.path.isfile(result_zip_path):
+                _convert_targz_to_zip(result_file_path, result_zip_path)
+                return await sanic.response.file(result_file_path)
         return await sanic.response.file(result_file_path)
         # file_stream is slow ? bad chunk size ?
         # return await sanic.response.file_stream(result_file_path, chunked=False)
@@ -222,6 +254,14 @@ async def job_post(request: sanic.request):
     return sanic.response.text(uuid.hex)
 
 
+if CONFIG["CIRCE_UPDATE_NOTIFY_ROUTE"]:
+
+    @server.route("/hook/", methods=["POST", "GET"])
+    async def notify_update(request: sanic.request):
+        Path("{}/upgrade_me".format(CONFIG["CIRCE_WORKING_DIR"])).touch()
+        return sanic.response.text("ok")
+
+
 if CONFIG["CIRCE_ENABLE_WEB_UI"]:
     cookie_signer = Signer(CONFIG["CIRCE_WEB_UI_CRYPT_KEY"])
 
@@ -319,8 +359,14 @@ if CONFIG["CIRCE_ENABLE_WEB_UI"]:
             CONFIG["CIRCE_WORKING_DIR"], job_id
         )
         if os.path.isfile(result_file_path):
+            result_zip_path = "{}done/{}.zip".format(
+                CONFIG["CIRCE_WORKING_DIR"], job_id
+            )
+            # end users prefer zip files over tar.gz
+            if not os.path.isfile(result_zip_path):
+                _convert_targz_to_zip(result_file_path, result_zip_path)
             return await sanic.response.file(
-                result_file_path, filename="{}.tar.gz".format(job_id)
+                result_zip_path, filename="{}.zip".format(job_id)
             )
         return sanic.response.HTTPResponse("Not Found", status=404)
 
