@@ -11,7 +11,6 @@ from requests.exceptions import ConnectionError, HTTPError
 import logging
 from inspect import getmembers, isfunction, isclass, signature
 import sys
-import os
 from pythonjsonlogger import jsonlogger
 import datetime
 
@@ -148,6 +147,12 @@ def do_transformations(uuid: uuid4, job_archive_path: str):
                 )
                 move(temp_zip_path, final_archive_path)
                 remove_file.schedule((final_archive_path,), delay=3600)
+                # should the web demo UI be used, there might be an additional zip file to remove
+                if CONFIG.get("CIRCE_ENABLE_WEB_UI"):
+                    final_zip_archive_path = "{}/done/{}.zip".format(
+                        CONFIG["CIRCE_WORKING_DIR"], uuid.hex
+                    )
+                    remove_file.schedule((final_zip_archive_path,), delay=3600)
                 if job_description.get("notify_hook", None):
                     try:
                         requests.post(  # request is blocking, maybe try xhttp once stable ?
